#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_ATAN2_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_ATAN2_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/scalar/atan2.hpp>

#endif
